@@ -7,14 +7,12 @@ import boto3
 class AbstractDynamoDB(abc.ABC):
     def __init__(self, table: str):
         db = boto3.resource("dynamodb")
-        self.table = db.Table(table)
+        self.table_name = table
+        self.table = db.Table(self.table_name)
 
     def put_item(self, *, data: dict[str, Any]) -> None:
         self.table.put_item(Item=data)
 
     def get_item(self, *, key: dict[str, Any]) -> Optional[Any]:
-        try:
-            return self.table.get_item(Key=key)
-        except:
-            pass
-        return None
+        response = self.table.get_item(Key=key)
+        return response.get("Item", None)
