@@ -8,7 +8,6 @@ from dynamodb.base import AbstractDynamoDB
 class DynamoDB(AbstractDynamoDB):
     def get_user(self, *, external_id: str, profile: str) -> Any:
         data = {"id": external_id, "profile": profile}
-        print(data)
         return self.get_item(key=data)
 
     def get_users(self) -> dict[str, Any]:
@@ -49,11 +48,11 @@ class DynamoDB(AbstractDynamoDB):
         updated_at = datetime.now().isoformat()
         set_expression = "SET "
         set_expression_list = []
-        if status:
+        if status is not None:
             set_expression_list.append("user_info.user_status = :user_status")
-        if messages:
+        if messages is not None:
             set_expression_list.append("user_info.messages = :messages")
-        if emails:
+        if emails is not None:
             set_expression_list.append("user_info.emails = :emails")
         set_expression_list.append("updated_at = :updated_at")
         set_expression += ", ".join(set_expression_list)
