@@ -69,7 +69,7 @@ class TalkyTimesAutomation(AbstractAutomation):
             "headers": headers,
             "referrer": f"{self.url}/search/all",
             "referrerPolicy": "strict-origin-when-cross-origin",
-            "body": json.dumps(body) if body else None,
+            "body": json.dumps(body) if body else {},
             "method": "POST",
             "mode": "cors",
             "credentials": "include"
@@ -91,11 +91,9 @@ class TalkyTimesAutomation(AbstractAutomation):
             )
             data = response.get("data")
             users = data.get("users")
-            print(users)
             if not len(users) > 0:
                 break
             for user in users:
-                print(user.get("id"))
                 self.db.create_or_update(
                     profile=self.profile,
                     external_id=str(user.get("id")),
